@@ -1,11 +1,9 @@
 import sys
-import logging
 import argparse
-from laboro.context import Context
+from laboro.context.workflow import Context
 from laboro.config.manager import Manager as CfgMgr
 from laboro.workflow import Workflow
 from laboro.logger.manager import Manager as LogMgr
-from laboro.vault import Vault
 
 
 def run(context, cfg_mgr):
@@ -18,10 +16,11 @@ def run(context, cfg_mgr):
 
 def main(workflows):
   cfg_mgr = CfgMgr(main_config="/etc/laboro/laboro.yml")
-  context = Context(logger=LogMgr(Vault()), config_mgr=cfg_mgr)
-  logging.getLogger("laboro.main").log_section("LABORO", "Bootstrapping")
+  log_mgr = LogMgr()
+  context = Context(log_mgr=log_mgr, config_mgr=cfg_mgr)
+  log_mgr.logger.log_section("LABORO", "Bootstrapping")
   for workflow_cfg in workflows:
-    logging.getLogger("laboro.main").vault.clear()
+    log_mgr.logger.vault.clear()
     cfg_mgr.workflow_config = workflow_cfg
     run(context=context, cfg_mgr=cfg_mgr)
 
