@@ -1,5 +1,9 @@
 import logging
 import traceback
+from laboro.logger import LaboroLogger
+
+logging.setLoggerClass(LaboroLogger)
+logger = logging.getLogger("laboro.main")
 
 
 class Handler:
@@ -26,7 +30,7 @@ class Handler:
       level = logging.CRITICAL
       exit_code = f"{kind.__name__}: {value}"
     exit_msg += f" {name} / {session} with {exit_code}"
-    logging.getLogger("laboro.main").log_section("WORKFLOW", exit_msg, level=level)
+    logger.log_section("WORKFLOW", exit_msg, level=level)
     if kind is not None and kind != SystemExit:
-      if logging.getLogger("laboro.main").getEffectiveLevel() <= logging.DEBUG:
+      if logger.getEffectiveLevel() <= logging.DEBUG:
         traceback.print_exc()
