@@ -4,6 +4,10 @@ import logging
 import importlib
 import subprocess
 from laboro.error import LaboroError
+from laboro.logger import LaboroLogger
+
+logging.setLoggerClass(LaboroLogger)
+logger = logging.getLogger("laboro.main")
 
 
 class Manager:
@@ -23,13 +27,13 @@ class Manager:
     try:
       reg = re.compile("^laboro_.*$|^laboro-.*$")
       if re.match(reg, package) is not None:
-        logging.info(f"[+] Installing package: {package}")
+        logger.info(f"[+] Installing package: {package}")
         subprocess.check_call([sys.executable, "-m", "pip", "-qqq", "install", package])
       else:
-        logging.critical(f"Package is not a valid Laboro package: {package}")
+        logger.critical(f"Package is not a valid Laboro package: {package}")
         raise LaboroError(f"InvalidPackageNameError: Package is not a valid Laboro package: {package}")
     except subprocess.CalledProcessError as err:
-      logging.critical(f"Unable to install Laboro package: {package}")
+      logger.critical(f"Unable to install Laboro package: {package}")
       raise LaboroError(f"InstallPackageError: Unable to install Laboro package: {package}") from err
 
   def register_class_from_module(self, cls, module):
@@ -65,14 +69,14 @@ class Manager:
         raise LaboroError(f"ClassNotFoundError: No such class: {module}.{cls}")
       if self.modules.get(module) is not None:
         if self.modules[module].get(cls) is None:
-          logging.info(f"[+] Registering class: {module}.{cls}")
+          logger.info(f"[+] Registering class: {module}.{cls}")
           self.modules[module][cls] = getattr(mod, cls)
       else:
-        logging.info(f"[+] Registering class: {module}.{cls}")
+        logger.info(f"[+] Registering class: {module}.{cls}")
         self.modules[module] = dict()
         self.modules[module][cls] = getattr(mod, cls)
     except ImportError as err:
-      logging.critical(f"No such module: {module}")
+      logger.critical(f"No such module: {module}")
       raise LaboroError(f"ModuleNotFoundError: No such module: {module}") from err
 
   def get_class_from_module(self, cls, module):
@@ -88,5 +92,5 @@ class Manager:
     try:
       return self.modules[module][cls]
     except KeyError as err:
-      logging.critical(f"No such class: {module}.{cls}")
+      logger.critical(f"No such class: {module}.{cls}")
       raise LaboroError(f"UnregisteredClassError: No such class: {module}.{cls}") from err
