@@ -1,5 +1,7 @@
+import os
 import copy
 import yaml
+from yamlinclude import YamlIncludeConstructor
 import logging
 import builtins
 from jsonschema import validate
@@ -144,7 +146,11 @@ class Validator:
 
   def _load_file(self, filepath):
     try:
+      base_dir = os.path.dirname(filepath)
+      YamlIncludeConstructor.add_to_loader_class(loader_class=yaml.FullLoader,
+                                                 base_dir=base_dir)
       with open(filepath, mode="r", encoding="utf-8") as schema:
+
         return yaml.load(schema, Loader=yaml.FullLoader)
     except FileNotFoundError as err:
       msg = {"type": "FileNotFoundError",
